==> GaiaScript-0.1.0.tar.gz: GaiaScript-0.1.0/gaia/_template.py <==
import os

from gaia import TEMPLATE_SCRIPTS_FOLDER
from gaia._exceptions import TemplateNotFoundException, TemplateAlreadyExistsException


class TemplateManager:
    @staticmethod
    def check_template_exists(func):
        def wrapper(self, *args, **kwargs):
            if not self.__is_template_exists(args[0]):
                raise TemplateNotFoundException(args[0])
            return func(self, *args, **kwargs)

        return wrapper

    def __init__(self, template_dir=TEMPLATE_SCRIPTS_FOLDER):
        self.template_dir = template_dir
        os.makedirs(template_dir, exist_ok=True)

    def get_all_templates(self) -> list[str]:
        return os.listdir(self.template_dir)

    def __is_template_exists(self, template_name) -> bool:
        return os.path.exists(
            os.path.join(self.template_dir, template_name)
        )

    def create_template(self, template_name, content) -> str:
        if self.__is_template_exists(template_name):
            raise TemplateAlreadyExistsException(template_name)
        return self.save_template(template_name, content)

    @check_template_exists
    def get_template_content(self, template_name) -> str:
        template_path = os.path.join(self.template_dir, template_name)
        with open(template_path, 'r') as f:
            return f.read()

    @check_template_exists
    def update_template(self, template_name, content) -> str:
        self.delete_template(template_name)
        return self.save_template(template_name, content)

    @check_template_exists
    def save_template(self, template_name, content) -> str:
        template_path = os.path.join(self.template_dir, template_name)
        with open(template_path, 'w') as f:
            f.write(content)
        return str(template_path)

    def delete_template(self, template_name) -> list[str]:
        template_path = os.path.join(self.template_dir, template_name)
        os.remove(template_path)
        return self.get_all_templates()

    @check_template_exists
    def get_template_path(self, template_name) -> str:
        return str(os.path.join(self.template_dir, template_name))

==> GaiaScript-0.1.1.1.tar.gz: GaiaScript-0.1.1.1/gaia/_template.py <==
import os

from gaia import TemplateNotFoundException, TemplateAlreadyExistsException


class TemplateManager:
    @staticmethod
    def check_template_exists(func):
        def wrapper(self, *args, **kwargs):
            if not self.__is_template_exists(args[0]):
                raise TemplateNotFoundException(args[0])
            return func(self, *args, **kwargs)

        return wrapper

    def __init__(self, template_dir):
        self.template_dir = template_dir
        os.makedirs(template_dir, exist_ok=True)

    def get_all_templates(self) -> list[str]:
        return os.listdir(self.template_dir)

    def __is_template_exists(self, template_name) -> bool:
        return os.path.exists(
            os.path.join(self.template_dir, template_name)
        )

    def create_template(self, template_name, content) -> str:
        if self.__is_template_exists(template_name):
            raise TemplateAlreadyExistsException(template_name)
        return self.save_template(template_name, content)

    @check_template_exists
    def get_template_content(self, template_name) -> str:
        template_path = os.path.join(self.template_dir, template_name)
        with open(template_path, 'r') as f:
            return f.read()

    @check_template_exists
    def update_template(self, template_name, content) -> str:
        self.delete_template(template_name)
        return self.save_template(template_name, content)

    @check_template_exists
    def save_template(self, template_name, content) -> str:
        template_path = os.path.join(self.template_dir, template_name)
        with open(template_path, 'w') as f:
            f.write(content)
        return str(template_path)

    def delete_template(self, template_name) -> list[str]:
        template_path = os.path.join(self.template_dir, template_name)
        os.remove(template_path)
        return self.get_all_templates()

    @check_template_exists
    def get_template_path(self, template_name) -> str:
        return str(os.path.join(self.template_dir, template_name))
